@@ -2,10 +2,9 @@ import pytz
 
 from django.core.exceptions import ValidationError
 from django.db import models
-from django.utils import six
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 
-from timezone_field.utils import is_pytz_instance
+from timezone_field.utils import is_pytz_instance, add_gmt_offset_to_choices
 
 
 class TimeZoneField(models.Field):
@@ -51,6 +50,7 @@ class TimeZoneField(models.Field):
 
         kwargs.setdefault('choices', self.CHOICES)
         kwargs.setdefault('max_length', self.MAX_LENGTH)
+        kwargs.setdefault('display_GMT_offset', False)
 
         # Choices can be specified in two forms: either
         # [<pytz.timezone>, <str>] or [<str>, <str>]
@@ -64,9 +64,13 @@ class TimeZoneField(models.Field):
         # use an alternate format. Representing the timezones as strings
         # is the obvious choice.
         choices = kwargs['choices']
-        if isinstance(choices[0][0], (six.string_types, six.binary_type)):
+        if isinstance(choices[0][0], (str, bytes)):
             kwargs['choices'] = [(pytz.timezone(n1), n2) for n1, n2 in choices]
 
+        if kwargs['display_GMT_offset']:
+            kwargs['choices'] = add_gmt_offset_to_choices(kwargs['choices'])
+        kwargs.pop('display_GMT_offset', None)
+
         super(TimeZoneField, self).__init__(*args, **kwargs)
 
     def validate(self, value, model_instance):
@@ -76,9 +80,9 @@ class TimeZoneField(models.Field):
 
     def deconstruct(self):
         name, path, args, kwargs = super(TimeZoneField, self).deconstruct()
-        if kwargs['choices'] == self.CHOICES:
+        if kwargs.get('choices') == self.CHOICES:
             del kwargs['choices']
-        if kwargs['max_length'] == self.MAX_LENGTH:
+        if kwargs.get('max_length') == self.MAX_LENGTH:
             del kwargs['max_length']
 
         # django can't decontruct pytz objects, so transform choices
@@ -116,7 +120,7 @@ class TimeZoneField(models.Field):
         if is_pytz_instance(value):
             return (value, value.zone)
         try:
-            return (pytz.timezone(force_text(value)), force_text(value))
+            return (pytz.timezone(force_str(value)), force_str(value))
         except pytz.UnknownTimeZoneError:
             pass
         raise ValidationError("Invalid timezone '%s'" % value)
